# 迅雷下载 JS-SDK 开发者文档

## 1. 简介

**迅雷下载 JS-SDK** 是由迅雷官方推出的产品，能够帮助您在网页中调用迅雷客户端下载文件。凭借迅雷强大的数据传输技术，能够大幅提升下载速度，同时有效降低服务器的带宽成本。

**主要特性**：

*   **多场景适用**：支持单文件或批量下载，支持下载文件夹并保持服务器目录结构，支持下载绿色版软件（游戏）并创建桌面快捷方式。
    
*   **多协议支持**：支持 HTTP、HTTPS、FTP、ed2k、Magnet、Thunder 等下载协议。
    
*   **全平台适配**：兼容 Windows、Android、iOS 和 macOS，并针对多设备与浏览器优化。
    
*   **无广告、安全可靠**：承诺无广告或恶意代码，持续更新功能。
    

[查看示例页面](http://open.thunderurl.com/test/edit.html)

您只需按照如下方法调用迅雷下载 JS-SDK，即可轻松满足各种下载需求。

---

## 2. 快速开始

### 2.1 引入 JS 文件

在网页中添加以下代码：

```html
<script src="//open.thunderurl.com/thunder-link.js"></script>  
```

⚠️ **注意**：使用 `//` 可自动适配页面协议（HTTP 或 HTTPS）。

---

### 2.2 创建下载任务

#### 下载单任务

使用 `thunderLink.newTask` 方法：

```javascript
thunderLink.newTask({  
  downloadDir: '下载目录名称', // 一级下载目录（可选）  
  tasks: [{  
    url: 'https://example.com/file.exe',  // 下载地址（必填）  
    name: 'file.exe', // 下载文件名（可选，含文件扩展名）  
    size: 123456  // 文件大小（可选，单位：字节）  
  }]  
});  
```

#### 下载批量任务

通过 `tasks` 字段指定多个文件：

```javascript
thunderLink.newTask({  
  downloadDir: '下载目录名称', // 一级下载目录（可选）  
  taskGroupName: '任务组名称', // 任务组和文件夹名称（可选）  
  tasks: [  
    { url: 'https://example.com/file1.exe', name: 'file1.exe', size: 1048576 },  
    { url: 'https://example.com/file2.exe', name: 'file2.exe', size: 2097152 }  
  ]  
});  
```

#### 下载绿色版软件（游戏）

将绿色版软件（游戏）的文件夹部署到服务器，然后通过 `tasks` 字段指定绿色版软件（游戏）的全部文件：

```javascript
thunderLink.newTask({  
  taskGroupName: '软件名称', // 任务组和文件夹名称（下载绿色版软件时为必填项）  
  excludePath: 'https://example.com/', // 需要从 URL 中排除的路径（必填）  
  installFile: 'Bin/main.exe', // 软件主程序（下载绿色版软件时为必填项）
  taskGroupIcon: 'https://example.com/icon.png', // 任务组图标（可选）
  downloadDir: '下载目录名称', // 一级下载目录（可选）  
  createShortcut: { // 下载完成后创建桌面快捷方式（可选）
    name: '软件名称', // 快捷方式的名称（创建快捷方式时为必填项）
    targetFile: 'Bin/main.exe', // 快捷方式指向文件的相对路径（创建快捷方式时为必填项）。
    runParams: '', // 运行参数（可选）
    startIn: '', // 起始位置（可选）
    }
  tasks: [  
    { url: 'https://example.com/Bin/main.exe', name: 'main.exe', size: 1048576 },
    { url: 'https://example.com/Data/file1.dat', name: 'file1.dat', size: 1048576 },  
    { url: 'https://example.com/Data/file2.dat', name: 'file2.dat', size: 2097152 }  
  ]  
});  
```

---

## 3. 参数说明

### 通用参数

|  参数名称  |  类型  |  描述  |  是否必填  |
| --- | --- | --- | --- |
|  **tasks**  |  Array  |  详见【下载任务参数】。  |  是  |
|  **downloadDir**  |  String  |  一级下载目录名称，该目录将创建于剩余存储空间最大的分区根目录，且不得包含操作系统不支持的字符。若此项未填写，则文件将下载至迅雷默认下载目录。  |  否  |
|  **taskGroupName**  |  String  |  任务组和文件夹名称，会在一级下载目录中创建一个文件夹保存下载的文件。  |  否  |
|  **excludePath**  |  String  |  让下载完成的文件保持服务器上的目录结构（以 URL 路径为参考），参数值为需要从 URL 中排除的路径。  |  否  |
|  **threadCount**  |  String  |  从原始地址进行下载的并发线程数，部分下载服务器会对单个 IP 的最大同时连接数予以限制。在此情况下，可将该项数值设定为 1，以避免被服务器断开连接。  |  否  |
|  **hideYunPan**  |  String  |  隐藏新建下载任务界面的“下载到云盘”功能，设置为 1 时生效。  |  否  |
|  **referer**  |  String  |  设置连接原始下载服务器时上报的 `referer`  |  否  |
|  **userAgent**  |  String  |  设置连接原始下载服务器时上报的 `userAgent`  |  否  |

### 下载任务参数

|  参数名称  |  类型  |  描述  |  是否必填  |
| --- | --- | --- | --- |
|  **url**  |  String  |  下载地址。支持 HTTP、HTTPS、FTP、ed2k、Magnet、Thunder 等下载协议。  |  是  |
|  **name**  |  String  |  文件名（含扩展名）。若不填，将自动获取。如果下载的文件很多，填写文件名可以绕过客户端获取文件名的步骤，从而加快创建任务的速度。  |  否  |
|  **size**  |  Number  |  文件大小，需传数字类型（单位：字节）。若不填，将自动获取。如果下载地址为 HTTP、HTTPS 协议，且下载的文件很多，填写文件大小有助于显示更准确的下载进度。  |  否  |
|  **dir**  |  String  |  当前 URL 对应的下载目录，相对于 `downloadDir/taskGroupName`。如果填写了 `excludePath` 则不会生效。  |  否  |

### 下载绿色版软件（游戏）专用参数

<div style="margin:2em 0;position:relative;transition:background 300ms, border 300ms;background: rgb(254, 248, 232);padding: 11px;border-radius: 8px;border: 1px solid rgb(254, 248, 232);"><div><div style="margin-top: 8px; margin-bottom: 8px; text-align: left; text-indent: 0px; padding-left: 0px; padding-right: 0px;"><span >鉴于下载绿色版软件（游戏）的参数存在被滥用的潜在风险，烦请您与我方取得联系，并说明您的使用场景。我方将进行安全性审查，审查通过后，会免费将您的下载地址的域名加入白名单，届时相关参数方可生效。</span></div></div></div>

|  参数名称  |  类型  |  描述  |  是否必填  |
| --- | --- | --- | --- |
|  **installFile**  |  String  |  绿色版软件（游戏）的主程序，传入任务组内文件的相对路径。填写该参数后，用户在迅雷中打开下载完成的任务组时，会直接启动主程序。  |  是  |
|  **taskGroupIcon**  |  String  |  任务组图标，传入图片 URL，图片内容通常为软件（游戏）的图标。  |  否  |
|  **createShortcut**  |  Object  |  下载完成后创建桌面快捷方式，本参数需配合 `taskGroupName` 使用。用户在迅雷中删除该任务组时，会一并删除桌面快捷方式。详见【创建桌面快捷方式参数】。  |  否  |

### 创建桌面快捷方式参数

|  参数名称  |  类型  |  描述  |  是否必填  |
| --- | --- | --- | --- |
|  **name**  |  String  |  快捷方式的名称。  |  是  |
|  **targetFile**  |  String  |  快捷方式所对应的任务组内部文件的相对路径。  |  是  |
|  **runParams**  |  String  |  快捷方式的运行参数  |  否  |
|  **startIn**  |  String  |  快捷方式的起始位置  |  否  |

---

## 4. 联系我们

如需更多帮助，请通过以下方式联系我们：

*   **产品经理微信**：yj10110
    
*   **QQ群**：754251297
    
*   **邮箱**：sdk@xunlei.com


<div class="copy-right" style="margin-top: 80px; text-align: center;  border-top: 1px solid #eee; padding-top: 20px; color: #999; font-size: 12px;">
  Copyright ©2005 深圳市迅雷网文化有限公司
  <a style="color: #999; font-size: 12px; font-weight: normal; text-decoration: none; margin-left: 4px;" href="http://beian.miit.gov.cn" target="_blank">粤ICP备13008231号</a>
</div>

